==> simg-1.0.0.21.zip: simg-project/application/view/compile/87ae6be608a886abe6c6fc6a193a05c7ef6e5e44.file.login.tpl.php <==
<?php /* Smarty version Smarty-3.1.19, created on 2015-04-24 11:32:31
         compiled from "C:\Users\yoshitake\Documents\User\products\simg\develop\simg-project\application\view\template\login.tpl" */ ?>
<?php /*%%SmartyHeaderCode:18635547d2f5e7cddf2-21249383%%*/if(!defined('SMARTY_DIR')) exit('no direct access allowed');
$_valid = $_smarty_tpl->decodeProperties(array (
  'file_dependency' => 
  array (
    '87ae6be608a886abe6c6fc6a193a05c7ef6e5e44' => 
    array (
      0 => 'C:\\Users\\yoshitake\\Documents\\User\\products\\simg\\develop\\simg-project\\application\\view\\template\\login.tpl',
      1 => 1429865575,
      2 => 'file',
    ),
    '0f6400e5bd88edcfc90ce21e2b8330fc68e25b72' => 
    array (
      0 => 'C:\\Users\\yoshitake\\Documents\\User\\products\\simg\\develop\\simg-project\\application\\view\\template\\base.tpl',
      1 => 1429865300,
      2 => 'file',
    ),
  ),
  'nocache_hash' => '18635547d2f5e7cddf2-21249383',
  'function' => 
  array (
  ),
  'version' => 'Smarty-3.1.19',
  'unifunc' => 'content_547d2f5e96fde2_53840405',
  'has_nocache_code' => false,
),false); /*/%%SmartyHeaderCode%%*/?>
<?php if ($_valid && !is_callable('content_547d2f5e96fde2_53840405')) {function content_547d2f5e96fde2_53840405($_smarty_tpl) {?><!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN""http://www.w3.org/TR/html4/loose.dtd">
<html lang="ja">
	<head>
		<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" href="<?php echo function_url(array('directory'=>((string)@constant('APP_NAME')),'query'=>((string)@constant('SIMG_PARAM_EVENT'))."=".((string)@constant('EVENT_CSS'))),$_smarty_tpl);?>
" type="text/css" />
		<script language="javascript" src="<?php echo function_url(array('directory'=>((string)@constant('APP_NAME')),'query'=>((string)@constant('SIMG_PARAM_EVENT'))."=".((string)@constant('EVENT_JS'))),$_smarty_tpl);?>
"></script>
		<title><?php echo $_smarty_tpl->getConfigVariable('PAGE_CAPTION');?>
</title>
		
		
	</head>
	<body>
		<div id="wrapper">
			<div id="header">
				
					<p><a href="<?php echo function_url(array('directory'=>((string)@constant('APP_NAME'))),$_smarty_tpl);?>
"><?php echo $_smarty_tpl->getConfigVariable('PAGE_TITLE');?>
</a></p>
				
			</div>
			<div id="commandbar">
				
				
			</div>
			<div id="container">
				

<div id="openarea">

<form method="post" action="<?php echo $_smarty_tpl->tpl_vars['action_url']->value;?>
">
<table width="100%" border=0>
<tr><td align="center" colspan=2><?php echo $_smarty_tpl->getConfigVariable('LOGIN_MESSAGE');?>
</td></tr>
<tr><td align="center" colspan=2>&nbsp;</td></tr>
<tr><td align="right" width="40%"><?php echo $_smarty_tpl->getConfigVariable('LOGIN_NAME');?>
</td><td align="left"><input type="text" name="<?php echo @constant('P_USER_NAME');?>
" /></td></tr>
<tr><td align="right"><?php echo $_smarty_tpl->getConfigVariable('LOGIN_PASSWORD');?>
</td><td align="left"><input type="password" name="<?php echo @constant('P_USER_PASSWORD');?>
" /></td></tr>
<?php if (isset($_smarty_tpl->tpl_vars['errmsg']->value)) {?>
	<tr><td align="center" colspan=2 id="error_message"><?php echo $_smarty_tpl->tpl_vars['errmsg']->value;?>
</td></tr>
<?php } else { ?>
	<tr><td align="center" colspan=2>&nbsp;</td></tr>
<?php }?>
<tr><td align="center" colspan=2><input type="submit" value="<?php echo $_smarty_tpl->getConfigVariable('LOGIN');?>
" /></td></tr>
</table>
</form>

</div>


			</div>
			<div id="footer">
				
					<p>Copyright 2014- System Concept All rights reserved.</p>
				
			</div>
		</div>
	</body>
</html>
<?php }} ?>

==> simg-2.0.30.zip: simg-project/application/view/compile/87ae6be608a886abe6c6fc6a193a05c7ef6e5e44.file.login.tpl.php <==
<?php /* Smarty version Smarty-3.1.19, created on 2015-04-28 14:33:04
         compiled from "C:\Users\yoshitake\Documents\User\products\simg\develop\simg-project\application\view\template\login.tpl" */ ?>
<?php /*%%SmartyHeaderCode:18635547d2f5e7cddf2-21249383%%*/if(!defined('SMARTY_DIR')) exit('no direct access allowed');
$_valid = $_smarty_tpl->decodeProperties(array (
  'file_dependency' => 
  array (
    '87ae6be608a886abe6c6fc6a193a05c7ef6e5e44' => 
    array (
      0 => 'C:\\Users\\yoshitake\\Documents\\User\\products\\simg\\develop\\simg-project\\application\\view\\template\\login.tpl',
      1 => 1429865575,
      2 => 'file',
    ),
    '0f6400e5bd88edcfc90ce21e2b8330fc68e25b72' => 
    array (
      0 => 'C:\\Users\\yoshitake\\Documents\\User\\products\\simg\\develop\\simg-project\\application\\view\\template\\base.tpl',
      1 => 1430223271,
      2 => 'file',
    ),
  ),
  'nocache_hash' => '18635547d2f5e7cddf2-21249383',
  'function' => 
  array (
  ),
  'version' => 'Smarty-3.1.19',
  'unifunc' => 'content_547d2f5e96fde2_53840405',
  'has_nocache_code' => false,
),false); /*/%%SmartyHeaderCode%%*/?>
<?php if ($_valid && !is_callable('content_547d2f5e96fde2_53840405')) {function content_547d2f5e96fde2_53840405($_smarty_tpl) {?><!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN""http://www.w3.org/TR/html4/loose.dtd">
<html lang="ja">
	<head>
		<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" href="<?php echo function_script(array('directory'=>((string)@constant('APP_NAME')),'path'=>'styles.css'),$_smarty_tpl);?>
" type="text/css" />
		<script language="javascript" src="<?php echo function_script(array('directory'=>((string)@constant('APP_NAME')),'path'=>'vote.js'),$_smarty_tpl);?>
"></script>
		<title><?php echo $_smarty_tpl->getConfigVariable('PAGE_CAPTION');?>
</title>
		
		
	</head>
	<body>
		<div id="wrapper">
			<div id="header">
				
					<p><a href="<?php echo function_url(array('directory'=>((string)@constant('APP_NAME'))),$_smarty_tpl);?>
"><?php echo $_smarty_tpl->getConfigVariable('PAGE_TITLE');?>
</a></p>
				
			</div>
			<div id="commandbar">
				
				
			</div>
			<div id="container">
				

<div id="openarea">

<form method="post" action="<?php echo $_smarty_tpl->tpl_vars['action_url']->value;?>
">
<table width="100%" border=0>
<tr><td align="center" colspan=2><?php echo $_smarty_tpl->getConfigVariable('LOGIN_MESSAGE');?>
</td></tr>
<tr><td align="center" colspan=2>&nbsp;</td></tr>
<tr><td align="right" width="40%"><?php echo $_smarty_tpl->getConfigVariable('LOGIN_NAME');?>
</td><td align="left"><input type="text" name="<?php echo @constant('P_USER_NAME');?>
" /></td></tr>
<tr><td align="right"><?php echo $_smarty_tpl->getConfigVariable('LOGIN_PASSWORD');?>
</td><td align="left"><input type="password" name="<?php echo @constant('P_USER_PASSWORD');?>
" /></td></tr>
<?php if (isset($_smarty_tpl->tpl_vars['errmsg']->value)) {?>
	<tr><td align="center" colspan=2 id="error_message"><?php echo $_smarty_tpl->tpl_vars['errmsg']->value;?>
</td></tr>
<?php } else { ?>
	<tr><td align="center" colspan=2>&nbsp;</td></tr>
<?php }?>
<tr><td align="center" colspan=2><input type="submit" value="<?php echo $_smarty_tpl->getConfigVariable('LOGIN');?>
" /></td></tr>
</table>
</form>

</div>


			</div>
			<div id="footer">
				
					<p>Copyright 2014- System Concept All rights reserved.</p>
				
			</div>
		</div>
	</body>
</html>
<?php }} ?>
